@@ -966,6 +966,173 @@ def pbdDict_bxReposRoot(
 
 
 
+####+BEGIN: bx:dblock:python:func :funcName "pbdDict_extRepos" :comment "pbd Dictionary" :funcType "Init" :retType "bxReposRootBaseDirsDict" :argsList "baseDir vcMode=None" :deco ""
+"""
+*  [[elisp:(org-cycle)][| ]] [[elisp:(org-show-subtree)][|=]] [[elisp:(show-children 10)][|V]] [[elisp:(bx:orgm:indirectBufOther)][|>]] [[elisp:(bx:orgm:indirectBufMain)][|I]] [[elisp:(blee:ppmm:org-mode-toggle)][|N]] [[elisp:(org-top-overview)][|O]] [[elisp:(progn (org-shifttab) (org-content))][|C]] [[elisp:(delete-other-windows)][|1]]  Func-Init      :: /pbdDict_extRepos/ =pbd Dictionary= retType=bxReposRootBaseDirsDict argsList=(baseDir vcMode=None)  [[elisp:(org-cycle)][| ]]
+"""
+def pbdDict_extRepos(
+    baseDir,
+    vcMode=None,
+):
+####+END:
+    """
+** In /lcnt/lgpc/bystar/permanent/common/clips/bxReposBasesInstall.tex
+*** See: \section{/bxRepos Bases Directory Structure Overview}
+    """
+
+    pbdDict = collections.OrderedDict()
+
+    #root = bxReposRoot_baseObtain(baseDir)
+    root = baseDir
+    pbdDict['/'] = bxpBaseDir.bxpObjGet_baseDir(root, '')
+
+    if not vcMode:
+        vcMode = "anon"
+    
+    
+    def fullDestPathGet(dstPathRel):
+        return( os.path.join(
+            root, dstPathRel,
+        ))
+
+    def directory(pathRel):
+        pbdDict[pathRel] = bxpBaseDir.bxpObjGet_baseDir(root, pathRel)
+
+    def symLink(dstPathRel, srcPath, srcPathType='internal'):
+        pbdDict[dstPathRel] = bxpBaseDir.bxpObjGet_symLink(root, dstPathRel, srcPath, srcPathType=srcPathType)
+
+    def command(dstPathRel, createCmnd):
+        # print("AAAA Entering command {createCmnd}".format(createCmnd=createCmnd))
+        pbdDict[dstPathRel] = bxpBaseDir.BxpBaseDir_Command(
+            destPathRoot=root,
+            destPathRel=dstPathRel,
+            createCommand=createCmnd,
+        )
+
+    #
+    # NOTYET, Change the name to: gitMapClone,
+    # Make it be
+    #    gitCloneBase(locPathRel, remGitRepoPath, vcMode)
+    #  A single gitMapClone can then do both gitClone() and gitCloneBase()
+    #  If basename of locPathRel and remGitRepoPath are the same, we then have gitClone()
+    #  Otherwise, gitCloneBase() which includes the move.
+    #
+        
+    def gitClone(dstPathRel, gitRepoPath, vcMode):
+        """ repoName of remGitRepoPath, is same as basename of dstPathRel"""
+        pathComps = os.path.split(dstPathRel)
+        baseDir = pathComps[0]
+        # repoName = pathComps[1]
+        if vcMode == "anon":
+            # git clone git://github.com/SomeUser/SomeRepo.git
+            #               "cd {root}/{baseDir} && git clone git@github.com:{gitRepoPath}.git"
+            command(
+                dstPathRel,
+                "cd {root}/{baseDir} && git clone git://github.com/{gitRepoPath}.git"
+                .format(root=root, baseDir=baseDir, gitRepoPath=gitRepoPath)
+            )
+        elif vcMode == "auth":
+            command(  dstPathRel,
+              "cd {root}/{baseDir} && git clone https://{gitUserName}:{gitPasswd}@github.com/{gitRepoPath}"
+              .format(root=root, baseDir=baseDir, gitUserName=gitUserName, gitPasswd=gitPasswd, gitRepoPath=gitRepoPath)
+            )
+        else:
+            icm.EH_problem_usageError("")
+
+
+    def gitCloneBase(locPathRel, remGitRepoPath, vcMode):
+        locBasenameRel = os.path.basename(locPathRel)
+        locDirnameRel =  os.path.dirname(locPathRel)
+        
+        locDirnameFull = os.path.join(root, locDirnameRel)
+        
+        repoName = os.path.basename(remGitRepoPath)
+
+        # This is the before the move to locPathRel location
+        locDirnamePlusRepoRel = os.path.join(locDirnameRel, repoName)        
+        
+        if vcMode == "anon":
+            # git clone git://github.com/SomeUser/SomeRepo.git
+            # "cd {locDirnameFull} && git clone git@github.com:{remGitRepoPath}.git"
+            #
+            # Note: Strange: You can not use multiple command() below.
+            # Not understood yet. To be revisited. MB-20200625
+            #
+            command(  locPathRel,
+                      "cd {locDirnameFull} && git clone git://github.com/{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
+                      .format(locDirnameFull=locDirnameFull, remGitRepoPath=remGitRepoPath, repoName=repoName, locBasenameRel=locBasenameRel)
+            )
+            
+        elif vcMode == "auth":
+            #
+            # Note: Strange: You can not use multiple command() below.
+            # Not understood yet. To be revisited. MB-20200625
+            #
+            command(  locDirnamePlusRepoRel,
+              "cd {locDirnameFull} && git clone https://{gitUserName}:{gitPasswd}@github.com/{remGitRepoPath} && mv {repoName} {locBasenameRel}"
+              .format(
+                  locDirnameFull=locDirnameFull,
+                  gitUserName=gitUserName,
+                  gitPasswd=gitPasswd,
+                  remGitRepoPath=remGitRepoPath,
+                  repoName=repoName,
+                  locBasenameRel=locBasenameRel
+              )
+            )
+            
+        else:
+            icm.EH_problem_usageError("")
+            
+            
+    #
+    # NOTYET, this is a hack for now. To Be replaced by bue.credentials
+    #
+
+    with open('/acct/employee/lsipusr/gitUserName', 'r') as myfile:
+        gitUserName=myfile.read().replace('\n', '')        
+
+    with open('/acct/employee/lsipusr/gitPasswd', 'r') as myfile:
+        gitPasswd=myfile.read().replace('\n', '')        
+
+    #
+    # NOTYET, the model of specifying one command here is wrong.
+    # We should be dealing with abstract directory bases, where
+    # each directory base has a create and verify method.
+    # Things like update and clean, etc should then be driven
+    # with the fto (File Tree Objects).
+    #
+    # So, gitCloneBase should be renamed gitReposCollectionBase and gitRepoBase
+    #
+
+    directory( 'emacs')
+    
+    gitClone(
+        'emacs/emacs-application-framework',
+        'manateelazycat/emacs-application-framework',
+        vcMode
+    )
+
+    gitClone(
+        'emacs/frame-cmds',
+        'emacsmirror/frame-cmds',
+        vcMode
+    )
+   
+    gitClone(
+        'emacs/frame-cmds',
+        'emacsmirror/frame-cmds',
+        vcMode
+    )
+
+    gitClone(
+        'emacs/thumb-frm',
+        'emacsmirror/thumb-frm',
+        vcMode
+    )
+
+    
+    
+    return pbdDict
 
 
 
